aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--device/include/llvm/Config/config.h2
-rw-r--r--host/include/llvm/Config/config.h2
-rw-r--r--include/llvm/Support/DataTypes.h112
-rw-r--r--lib/CodeGen/Android.mk1
-rw-r--r--lib/CodeGen/AsmPrinter/Android.mk1
-rw-r--r--lib/CodeGen/SelectionDAG/Android.mk1
-rw-r--r--llvm-device-build.mk1
-rw-r--r--llvm-host-build.mk1
-rw-r--r--utils/TableGen/Android.mk1
9 files changed, 113 insertions, 9 deletions
diff --git a/device/include/llvm/Config/config.h b/device/include/llvm/Config/config.h
index 593199c..c2599c9 100644
--- a/device/include/llvm/Config/config.h
+++ b/device/include/llvm/Config/config.h
@@ -481,7 +481,7 @@
#define LLVM_ETCDIR "/usr/local/google/llvm/etc/llvm"
/* Host triple we were built on */
-#define LLVM_HOSTTRIPLE "x86_64-unknown-linux-gnu"
+#define LLVM_DEFAULT_TARGET_TRIPLE "x86_64-unknown-linux-gnu"
/* Installation directory for include files */
#define LLVM_INCLUDEDIR "/usr/local/google/llvm/include"
diff --git a/host/include/llvm/Config/config.h b/host/include/llvm/Config/config.h
index 817cf43..a2d1f4e 100644
--- a/host/include/llvm/Config/config.h
+++ b/host/include/llvm/Config/config.h
@@ -473,7 +473,7 @@
#define LLVM_ETCDIR "/usr/local/google/llvm/etc/llvm"
/* Host triple we were built on */
-#define LLVM_HOSTTRIPLE "i386-unknown-linux"
+#define LLVM_DEFAULT_TARGET_TRIPLE "i386-unknown-linux"
/* Installation directory for include files */
#define LLVM_INCLUDEDIR "/usr/local/google/llvm/include"
diff --git a/lib/CodeGen/Android.mk b/lib/CodeGen/Android.mk
index 79571a7..adef8ef 100644
--- a/lib/CodeGen/Android.mk
+++ b/lib/CodeGen/Android.mk
@@ -39,6 +39,7 @@ codegen_SRC_FILES := \
LocalStackSlotAllocation.cpp \
MachineBasicBlock.cpp \
MachineBlockFrequencyInfo.cpp \
+ MachineBlockPlacement.cpp \
MachineBranchProbabilityInfo.cpp \
MachineCSE.cpp \
MachineDominators.cpp \
diff --git a/lib/CodeGen/AsmPrinter/Android.mk b/lib/CodeGen/AsmPrinter/Android.mk
index 843ff24..d5496de 100644
--- a/lib/CodeGen/AsmPrinter/Android.mk
+++ b/lib/CodeGen/AsmPrinter/Android.mk
@@ -13,6 +13,7 @@ LOCAL_SRC_FILES := \
AsmPrinterInlineAsm.cpp \
ARMException.cpp \
DIE.cpp \
+ DwarfAccelTable.cpp \
DwarfCFIException.cpp \
DwarfCompileUnit.cpp \
DwarfDebug.cpp \
diff --git a/lib/CodeGen/SelectionDAG/Android.mk b/lib/CodeGen/SelectionDAG/Android.mk
index 2937196..4fc5cc9 100644
--- a/lib/CodeGen/SelectionDAG/Android.mk
+++ b/lib/CodeGen/SelectionDAG/Android.mk
@@ -13,7 +13,6 @@ codegen_selectiondag_SRC_FILES := \
LegalizeVectorOps.cpp \
LegalizeVectorTypes.cpp \
ScheduleDAGFast.cpp \
- ScheduleDAGList.cpp \
ScheduleDAGRRList.cpp \
ScheduleDAGSDNodes.cpp \
SelectionDAG.cpp \
diff --git a/llvm-device-build.mk b/llvm-device-build.mk
index e1ce56d..47b59af 100644
--- a/llvm-device-build.mk
+++ b/llvm-device-build.mk
@@ -2,6 +2,7 @@ LOCAL_CFLAGS := \
-D_GNU_SOURCE \
-D__STDC_LIMIT_MACROS \
-D__STDC_CONSTANT_MACROS \
+ -D__STDC_FORMAT_MACROS \
-O2 \
-fomit-frame-pointer \
-Wall \
diff --git a/llvm-host-build.mk b/llvm-host-build.mk
index 5219efd..b13d381 100644
--- a/llvm-host-build.mk
+++ b/llvm-host-build.mk
@@ -2,6 +2,7 @@ LOCAL_CFLAGS := \
-D_GNU_SOURCE \
-D__STDC_LIMIT_MACROS \
-D__STDC_CONSTANT_MACROS \
+ -D__STDC_FORMAT_MACROS \
-O2 \
-fomit-frame-pointer \
-Wall \
diff --git a/utils/TableGen/Android.mk b/utils/TableGen/Android.mk
index 28de64f..673f1f5 100644
--- a/utils/TableGen/Android.mk
+++ b/utils/TableGen/Android.mk
@@ -1,7 +1,6 @@
LOCAL_PATH:= $(call my-dir)
tablegen_SRC_FILES := \
- ARMDecoderEmitter.cpp \
AsmMatcherEmitter.cpp \
AsmWriterEmitter.cpp \
AsmWriterInst.cpp \
diff --git a/include/llvm/Support/DataTypes.h b/include/llvm/Support/DataTypes.h
index d325c66..a4a65b8 100644
--- a/include/llvm/Support/DataTypes.h
+++ b/include/llvm/Support/DataTypes.h
@@ -1,4 +1,5 @@
/*===-- include/System/DataTypes.h - Define fixed size types -----*- C -*-===*\
|* *|
|* The LLVM Compiler Infrastructure *|
|* *|
@@ -15,12 +16,14 @@
|* [u]int(32|64)_t : typedefs for signed and unsigned 32/64 bit system types*|
|* [U]INT(8|16|32|64)_(MIN|MAX) : Constants for the min and max values. *|
|* *|
-|* No library is required when using these functinons. *|
+|* No library is required when using these functions. *|
|* *|
|*===----------------------------------------------------------------------===*/
/* Please leave this file C-compatible. */
+/* Please keep this file in sync with DataTypes.h.cmake */
+
#ifndef SUPPORT_DATATYPES_H
#define SUPPORT_DATATYPES_H
@@ -36,17 +39,19 @@
#include <math.h>
#endif
+#ifndef _MSC_VER
+
/* Note that this header's correct operation depends on __STDC_LIMIT_MACROS
being defined. We would define it here, but in order to prevent Bad Things
happening when system headers or C++ STL headers include stdint.h before we
define it here, we define it on the g++ command line (in Makefile.rules). */
#if !defined(__STDC_LIMIT_MACROS)
-# error "Must #define __STDC_LIMIT_MACROS before #including System/DataTypes.h"
+# error "Must #define __STDC_LIMIT_MACROS before #including Support/DataTypes.h"
#endif
#if !defined(__STDC_CONSTANT_MACROS)
# error "Must #define __STDC_CONSTANT_MACROS before " \
- "#including System/DataTypes.h"
+ "#including Support/DataTypes.h"
#endif
/* Note that <inttypes.h> includes <stdint.h>, if this is a C99 system. */
@@ -63,7 +68,7 @@
#endif
#ifdef _AIX
-#include "llvm/System/AIXDataTypesFix.h"
+#include "llvm/Support/AIXDataTypesFix.h"
#endif
/* Handle incorrect definition of uint64_t as u_int64_t */
@@ -87,6 +92,103 @@ typedef u_int64_t uint64_t;
#define UINT32_MAX 4294967295U
#endif
+#else /* _MSC_VER */
+/* Visual C++ doesn't provide standard integer headers, but it does provide
+ built-in data types. */
+#include <stdlib.h>
+#include <stddef.h>
+#include <sys/types.h>
+#ifdef __cplusplus
+#include <cmath>
+#else
+#include <math.h>
+#endif
+typedef __int64 int64_t;
+typedef unsigned __int64 uint64_t;
+typedef signed int int32_t;
+typedef unsigned int uint32_t;
+typedef short int16_t;
+typedef unsigned short uint16_t;
+typedef signed char int8_t;
+typedef unsigned char uint8_t;
+typedef signed int ssize_t;
+#ifndef INT8_MAX
+# define INT8_MAX 127
+#endif
+#ifndef INT8_MIN
+# define INT8_MIN -128
+#endif
+#ifndef UINT8_MAX
+# define UINT8_MAX 255
+#endif
+#ifndef INT16_MAX
+# define INT16_MAX 32767
+#endif
+#ifndef INT16_MIN
+# define INT16_MIN -32768
+#endif
+#ifndef UINT16_MAX
+# define UINT16_MAX 65535
+#endif
+#ifndef INT32_MAX
+# define INT32_MAX 2147483647
+#endif
+#ifndef INT32_MIN
+/* MSC treats -2147483648 as -(2147483648U). */
+# define INT32_MIN (-INT32_MAX - 1)
+#endif
+#ifndef UINT32_MAX
+# define UINT32_MAX 4294967295U
+#endif
+/* Certain compatibility updates to VC++ introduce the `cstdint'
+ * header, which defines the INT*_C macros. On default installs they
+ * are absent. */
+#ifndef INT8_C
+# define INT8_C(C) C##i8
+#endif
+#ifndef UINT8_C
+# define UINT8_C(C) C##ui8
+#endif
+#ifndef INT16_C
+# define INT16_C(C) C##i16
+#endif
+#ifndef UINT16_C
+# define UINT16_C(C) C##ui16
+#endif
+#ifndef INT32_C
+# define INT32_C(C) C##i32
+#endif
+#ifndef UINT32_C
+# define UINT32_C(C) C##ui32
+#endif
+#ifndef INT64_C
+# define INT64_C(C) C##i64
+#endif
+#ifndef UINT64_C
+# define UINT64_C(C) C##ui64
+#endif
+
+#ifndef PRId64
+# define PRId64 "I64d"
+#endif
+#ifndef PRIi64
+# define PRIi64 "I64i"
+#endif
+#ifndef PRIo64
+# define PRIo64 "I64o"
+#endif
+#ifndef PRIu64
+# define PRIu64 "I64u"
+#endif
+#ifndef PRIx64
+# define PRIx64 "I64x"
+#endif
+#ifndef PRIX64
+# define PRIX64 "I64X"
+#endif
+
+#endif /* _MSC_VER */
+
/* Set defaults for constants which we cannot find. */
#if !defined(INT64_MAX)
# define INT64_MAX 9223372036854775807LL
@@ -1,4 +1,5 @@
-/*===-- include/System/DataTypes.h - Define fixed size types -----*- C -*-===*\
+/* include/llvm/Support/DataTypes.h. Generated from DataTypes.h.in by configure. */
+/*===-- include/Support/DataTypes.h - Define fixed size types -----*- C -*-===*\
|* *|
|* The LLVM Compiler Infrastructure *|